<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/buttonoverlay.cpp" line="143"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtConfigArguments</name>
    <message>
        <location filename="../resources/qtconfigarguments.cpp" line="193"/>
        <source>This application requires Windows 10, version 1809 or newer. The current Windows version is older so the application might not work correctly.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::QtLanguageOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtsettings.cpp" line="566"/>
        <source>recognized by Qt as</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::QtOptionCategory</name>
    <message>
        <location filename="../settingsdialog/qtsettings.cpp" line="420"/>
        <source>Qt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities</name>
    <message>
        <location filename="../resources/resources.cpp" line="403"/>
        <source>unable to access file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="406"/>
        <source>file has invalid format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="409"/>
        <source>unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resources/resources.cpp" line="411"/>
        <source>Unable to sync settings from &quot;%1&quot;: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::AboutDialog</name>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="24"/>
        <location filename="../aboutdialog/aboutdialog.cpp" line="139"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="127"/>
        <source>application name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="137"/>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="163"/>
        <source>description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="185"/>
        <source>website link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="226"/>
        <source>creators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.ui" line="253"/>
        <source>Using Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="62"/>
        <source>developed by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
        <source>Linked against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="80"/>
        <source>For updates and bug reports visit the &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;project website&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/aboutdialog.cpp" line="99"/>
        <source>Using &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::EnterPasswordDialog</name>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="12"/>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="51"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
        <source>Enter the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="64"/>
        <source>user name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="86"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="102"/>
        <source>repeat password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="130"/>
        <source>show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="137"/>
        <source>don&apos;t use a password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="213"/>
        <source>Capslock is active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="239"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.ui" line="254"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
        <source>Enter the new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="289"/>
        <source>You didn&apos;t enter a user name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="291"/>
        <source>You didn&apos;t enter a password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="296"/>
        <source>You have to enter the new password twice to ensure you enterd it correct.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="299"/>
        <source>You mistyped the password.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::PaletteEditor</name>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="20"/>
        <source>Edit Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="53"/>
        <source>Tune Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="84"/>
        <source>Show Detai&amp;ls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="91"/>
        <source>&amp;Compute Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.ui" line="101"/>
        <source>Quick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="46"/>
        <source>Save…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="48"/>
        <source>Load…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
        <source>Color palette configuration (*.ini)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="162"/>
        <source>Unable to load &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="167"/>
        <source>&quot;%1&quot; does not contain a valid palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="180"/>
        <source>Unable to write &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="188"/>
        <source>Load palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
        <source>Error reading palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="206"/>
        <source>Save palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="214"/>
        <source>Error writing palette</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::PaletteModel</name>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="416"/>
        <source>Color Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="418"/>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="420"/>
        <source>Inactive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../paletteeditor/paletteeditor.cpp" line="422"/>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::PathSelection</name>
    <message>
        <location filename="../widgets/pathselection.cpp" line="87"/>
        <location filename="../widgets/pathselection.cpp" line="144"/>
        <source>Select ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="92"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="95"/>
        <source>Explore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/pathselection.cpp" line="131"/>
        <location filename="../widgets/pathselection.cpp" line="133"/>
        <source>Select path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtAppearanceOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="21"/>
        <source>Use system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="34"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="71"/>
        <source>More options ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="93"/>
        <source>Widget style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="132"/>
        <source>Style sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="162"/>
        <source>Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="175"/>
        <source>select ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="195"/>
        <source>Icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtappearanceoptionpage.ui" line="249"/>
        <source>These settings take effect after restarting the application.
These settings might be overwritten by your Qt platform integration plugin and hence have no effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtEnvOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="14"/>
        <source>Environment/paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="28"/>
        <source>Additional plugin directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="38"/>
        <source>Additional icon theme search path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="48"/>
        <source>Additional translation search path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtenvoptionpage.ui" line="79"/>
        <source>These settings take effect after restarting the application.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::QtLanguageOptionPage</name>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="6"/>
        <source>Localization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="43"/>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="53"/>
        <source>Use system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/qtlanguageoptionpage.ui" line="98"/>
        <source>These settings take effect after restarting the application.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::RecentMenuManager</name>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="35"/>
        <source>&amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="38"/>
        <source>&amp;Clear list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="144"/>
        <source>Recently opened files - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="145"/>
        <source>The selected file can&apos;t be found anymore. Do you want to delete the obsolete entry from the list?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="148"/>
        <source>keep entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/recentmenumanager.cpp" line="149"/>
        <source>delete entry</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtUtilities::SettingsDialog</name>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="14"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog/settingsdialog.cpp" line="153"/>
        <source>No category selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="93"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="134"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="148"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.ui" line="159"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.cpp" line="320"/>
        <source>&lt;p&gt;&lt;b&gt;Errors occurred when applying changes:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog/settingsdialog.cpp" line="325"/>
        <source>unknown error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utilities::windowTitle</name>
    <message>
        <location filename="../misc/dialogutils.cpp" line="36"/>
        <source>Unsaved - %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="39"/>
        <source>%1 - %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="44"/>
        <source>*Unsaved - %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dialogutils.cpp" line="47"/>
        <source>*%1 - %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
